@@ -60,7 +60,7 @@ class SocketStreamReader:
 
 class CodeGuru:
     tcp = None
-    host = "145.239.88.127"
+    host = "5.196.92.155"
     port = 6341
     sr = None
 
@@ -74,7 +74,7 @@ class CodeGuru:
     @staticmethod
     def readString(name):
         CodeGuru.tcp.send(f"get {name}\n".encode())
-        resp = CodeGuru.sr.readline()
+        resp = CodeGuru.sr.readline().strip()
         return resp.decode('utf-8').strip()
 
     @staticmethod
@@ -84,7 +84,7 @@ class CodeGuru:
     @staticmethod
     def readDictionary(name):
         CodeGuru.tcp.send(f"get {name}\n".encode())
-        resp = CodeGuru.sr.readline()
+        resp = CodeGuru.sr.readline().strip()
         dict = json.loads(resp) if resp.isspace() == False else None
         return dict
 
@@ -97,7 +97,7 @@ class CodeGuru:
     def entriesList():
         CodeGuru.tcp.send(f"list\n".encode())
         resp = CodeGuru.sr.readline()
-        return resp.decode().split(',')
+        return resp.decode().strip().split(',')
 
     @staticmethod
     def removeEntry(name):
